========================
Thread-Local Storage API 
========================

:Author: Etienne Robillard <tkadm30@yandex.com>
:Version: 0.7.6

The ``notmm.datastore.threadlocal`` module provides a simple
thread-local based storage backend. 

